==> haskell-ini-0.3.5-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-ini.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ini
version: 0.3.5
id: ini-0.3.5-58JLCjdFfTNKmag3fygGSA
key: ini-0.3.5-58JLCjdFfTNKmag3fygGSA
license: BSD3
copyright: 2013 Chris Done
maintainer: chrisdone@gmail.com
homepage: http://github.com/chrisdone/ini
synopsis: Quick and easy configuration files in the INI format.
description:
    Quick and easy configuration files in the INI format.
category: Data, Configuration
author: Chris Done
exposed: True
indefinite: False
exposed-modules:
    Data.Ini
abi: 61cb9aa1c4cd25dbccace4d16a4be6ec
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/ini-0.3.5
library-dirs: /usr/lib/ghc-8.2.2/site-local/ini-0.3.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/ini-0.3.5
hs-libraries: HSini-0.3.5-58JLCjdFfTNKmag3fygGSA
depends:
    base-4.10.1.0 attoparsec-0.13.2.2-ImfqXHsnQ0kLjIvcUXLfco
    text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj
    unordered-containers-0.2.9.0-GlwZSbNHLsw5b3PDCuUikn
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             attoparsec-0.13.2.2-ImfqXHsnQ0kLjIvcUXLfco=02dde2665ea78b3a3aa2c59359e39730
             text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj=d51c5ac73448d7d6c9cbe4dedb95457e
             unordered-containers-0.2.9.0-GlwZSbNHLsw5b3PDCuUikn=e523ad11a5c5a0977b92d6afb6220c8b
haddock-interfaces: /usr/share/doc/haskell-ini/html/ini.haddock
haddock-html: /usr/share/doc/haskell-ini/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ini-0.3.5-16-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-ini.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ini
version: 0.3.5
id: ini-0.3.5-Efib8TK5uAY8JUDnWMpZZ3
key: ini-0.3.5-Efib8TK5uAY8JUDnWMpZZ3
license: BSD3
copyright: 2013 Chris Done
maintainer: chrisdone@gmail.com
homepage: http://github.com/chrisdone/ini
synopsis: Quick and easy configuration files in the INI format.
description:
    Quick and easy configuration files in the INI format.
category: Data, Configuration
author: Chris Done
exposed: True
indefinite: False
exposed-modules:
    Data.Ini
abi: 08a871cce43718a933d2a2f0c92b8e0a
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/ini-0.3.5
library-dirs: /usr/lib/ghc-8.2.2/site-local/ini-0.3.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/ini-0.3.5
hs-libraries: HSini-0.3.5-Efib8TK5uAY8JUDnWMpZZ3
depends:
    base-4.10.1.0 attoparsec-0.13.2.2-1iFrnKzrZDOGKCpRsHPeZj
    text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj
    unordered-containers-0.2.9.0-BDwE3H9gLbqBuONTkERyOz
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             attoparsec-0.13.2.2-1iFrnKzrZDOGKCpRsHPeZj=9d8982f8b70cf41a2e1b007eb9382565
             text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj=d51c5ac73448d7d6c9cbe4dedb95457e
             unordered-containers-0.2.9.0-BDwE3H9gLbqBuONTkERyOz=9d795026e0df763f1ffeaf92b7adcdda
haddock-interfaces: /usr/share/doc/haskell-ini/html/ini.haddock
haddock-html: /usr/share/doc/haskell-ini/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
